@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2021 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -194,6 +194,9 @@ class Search(object):
             else:
                 whereDbsQuery = ""
 
+            if dbCond and conf.exclude:
+                whereDbsQuery += " AND %s NOT LIKE '%s'" % (dbCond, re.sub(r"\.[*+]", '%', conf.exclude._original))
+
             logger.info(infoMsg)
 
             tblQuery = "%s%s" % (tblCond, tblCondParam)
@@ -431,6 +434,9 @@ class Search(object):
                 else:
                     infoMsgDb = " across all databases"
 
+                if conf.exclude:
+                    whereDbsQuery += " AND %s NOT LIKE '%s'" % (dbCond, re.sub(r"\.[*+]", '%', conf.exclude._original))
+
             logger.info("%s%s%s" % (infoMsg, infoMsgTbl, infoMsgDb))
 
             colQuery = "%s%s" % (colCond, colCondParam)
