@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2021 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -84,7 +84,7 @@ class Takeover(Abstraction, Metasploit, ICMPsh, Registry):
         try:
             self.initEnv(web=web)
         except SqlmapFilePathException:
-            if not web:
+            if not web and not conf.direct:
                 infoMsg = "falling back to web backdoor method..."
                 logger.info(infoMsg)
 
