@@ -595,7 +595,7 @@ class Tag(PageElement):
         stopNode = self._lastRecursiveChild().next
         strings = []
         current = self.contents[0]
-        while current is not stopNode:
+        while current and current is not stopNode:
             if isinstance(current, NavigableString):
                 strings.append(current.strip())
             current = current.next
@@ -897,7 +897,7 @@ class Tag(PageElement):
             return  # Note: https://stackoverflow.com/a/30217723 (PEP 479)
         stopNode = self._lastRecursiveChild().next
         current = self.contents[0]
-        while current is not stopNode:
+        while current and current is not stopNode:
             yield current
             current = current.next
 
